'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TestRecorder = undefined;

var _testRecorder = require('./test-recorder');

var _testRecorder2 = _interopRequireDefault(_testRecorder);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var reduxRecord = function reduxRecord(reducer) {
  var equality = arguments.length <= 1 || arguments[1] === undefined ? function (result, nextState) {
    return result === nextState;
  } : arguments[1];

  var initState = undefined;
  var actions = [];
  var recording = false;
  var showingTest = false;
  var stringifiedReducer = reducer.toString();
  var equalityFunction = equality.toString();
  var startRecord = function startRecord() {
    return recording = true;
  };
  var stopRecord = function stopRecord() {
    recording = false;
    showingTest = true;
  };
  var getRecordingStatus = function getRecordingStatus() {
    return recording;
  };
  var shouldShowTest = function shouldShowTest() {
    return showingTest;
  };
  var hideTest = function hideTest() {
    actions = [];
    showingTest = false;
    initState = undefined;
  };
  var getTest = function getTest() {
    return 'var test = require(\'tape\');\n      var state = ' + initState + ';\n      var reducer = ' + stringifiedReducer + ';\n      var equality = ' + equalityFunction + ';\n      test(\'expected state returned for each action\', function(assert) {\n        var actions = ' + JSON.stringify(actions, 4) + ';\n        var returnExpectedState = actions.map(function (action) {\n          var result = reducer(state, action.action);\n          state = result;\n          return equality(result, action.nextState);\n        });\n        assert.ok(returnExpectedState.every(function(expected) { return expected }), \'expected state returned for each action\');\n        assert.end();\n      });';
  };
  var middleware = function middleware(_ref) {
    var getState = _ref.getState;
    return function (next) {
      return function (action) {
        if (initState === undefined) {
          initState = getState();
        }
        next(action);
        if (recording) {
          var nextState = getState();
          actions.push({ action: action, nextState: nextState });
        }
      };
    };
  };
  var props = { getRecordingStatus: getRecordingStatus, startRecord: startRecord, stopRecord: stopRecord, getTest: getTest, shouldShowTest: shouldShowTest, hideTest: hideTest };
  return { middleware: middleware, props: props };
};
exports.TestRecorder = _testRecorder2.default;
exports.default = reduxRecord;